@@ -15,7 +15,6 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "config.h"
 
 #include <errno.h>
 #include <new>
@@ -40,17 +39,15 @@
 //***************************************************************************
 Kwave::FilterPlugin::FilterPlugin(QObject *parent, const QVariantList &args)
     :Kwave::Plugin(parent, args),
-     m_params(), m_listen(false), m_pause(false), m_sink(Q_NULLPTR)
+     m_params(), m_listen(false), m_pause(false), m_sink(nullptr)
 {
 }
 
 //***************************************************************************
 Kwave::FilterPlugin::~FilterPlugin()
 {
-    if (m_sink) {
-        delete m_sink;
-        m_sink = Q_NULLPTR;
-    }
+    delete m_sink;
+    m_sink = nullptr;
 }
 
 //***************************************************************************
@@ -63,7 +60,7 @@ QStringList *Kwave::FilterPlugin::setup(QStringList &previous_params)
     // create the setup dialog
     Kwave::PluginSetupDialog *setup_dialog = createDialog(parentWidget());
     Q_ASSERT(setup_dialog);
-    if (!setup_dialog) return Q_NULLPTR;
+    if (!setup_dialog) return nullptr;
 
     // connect the signals for the pre-listen handling
     QDialog *dlg = setup_dialog->dialog();
@@ -83,18 +80,18 @@ QStringList *Kwave::FilterPlugin::setup(QStringList &previous_params)
         *list = setup_dialog->params();
     } else {
         // user pressed "Cancel"
-        if (list) delete list;
-        list = Q_NULLPTR;
+        delete list;
+        list = nullptr;
     }
 
-    if (setup_dialog) delete setup_dialog;
+    delete setup_dialog;
     return list;
 }
 
 //***************************************************************************
 void Kwave::FilterPlugin::run(QStringList params)
 {
-    Kwave::UndoTransactionGuard *undo_guard = Q_NULLPTR;
+    Kwave::UndoTransactionGuard *undo_guard = nullptr;
     m_pause = false;
 
     if (!interpreteParameters(params)) m_params = params;
@@ -106,7 +103,8 @@ void Kwave::FilterPlugin::run(QStringList params)
     // switch to interactive mode in pre-listen mode
     Kwave::StreamObject::setInteractive(m_listen);
 
-    Kwave::SampleSource *filter = createFilter(tracks.count());
+    Kwave::SampleSource *filter =
+        createFilter(static_cast<unsigned int>(tracks.count()));
     Q_ASSERT(filter);
 
     // create all objects
@@ -125,7 +123,7 @@ void Kwave::FilterPlugin::run(QStringList params)
             Kwave::UndoTransactionGuard(*this, actionName());
         Q_ASSERT(undo_guard);
         if (!undo_guard) {
-            if (filter) delete filter;
+            delete filter;
             Kwave::StreamObject::setInteractive(false);
             return;
         }
@@ -134,10 +132,10 @@ void Kwave::FilterPlugin::run(QStringList params)
         Q_ASSERT(m_sink);
     }
     if (!filter || !m_sink || m_sink->done()) {
-        if (filter)     delete filter;
-        if (undo_guard) delete undo_guard;
-        if (m_sink)     delete m_sink;
-        m_sink = Q_NULLPTR;
+        delete filter;
+        delete undo_guard;
+        delete m_sink;
+        m_sink = nullptr;
         Kwave::StreamObject::setInteractive(false);
         return;
     }
@@ -184,12 +182,12 @@ void Kwave::FilterPlugin::run(QStringList params)
     }
 
     // cleanup
-    if (filter)     delete filter;
+    delete filter;
     if (!m_listen) {
         delete m_sink;
-        m_sink = Q_NULLPTR;
+        m_sink = nullptr;
     }
-    if (undo_guard) delete undo_guard;
+    delete undo_guard;
 
     m_pause  = false;
     m_listen = false;
@@ -214,8 +212,9 @@ void Kwave::FilterPlugin::updateFilter(Kwave::SampleSource * /*filter*/,
 void Kwave::FilterPlugin::startPreListen()
 {
     Q_ASSERT(!m_sink);
-    if (m_sink) delete m_sink;
-    m_sink = manager().openMultiTrackPlayback(selectedTracks().count());
+    delete m_sink;
+    m_sink = manager().openMultiTrackPlayback(
+        static_cast<unsigned int>(selectedTracks().count()));
 
     if (m_sink) {
         m_listen = true;
@@ -231,8 +230,8 @@ void Kwave::FilterPlugin::stopPreListen()
     stop();
     m_listen = false;
     setProgressDialogEnabled(true);
-    if (m_sink) delete m_sink;
-    m_sink = Q_NULLPTR;
+    delete m_sink;
+    m_sink = nullptr;
 }
 
 //***************************************************************************
@@ -243,3 +242,5 @@ QString Kwave::FilterPlugin::progressText()
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_FilterPlugin.cpp"
