@@ -15,7 +15,6 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "config.h"
 
 #include "libkwave/String.h"
 
@@ -44,7 +43,7 @@ void Kwave::MenuList::clear()
 
     QString list_uid = name();
     Kwave::MenuNode *child;
-    while ((child = parent->findUID(list_uid)) != Q_NULLPTR)
+    while ((child = parent->findUID(list_uid)) != nullptr)
         parent->removeChild(child);
 }
 
@@ -60,8 +59,10 @@ Kwave::MenuNode *Kwave::MenuList::insertLeaf(const QString &name,
     Q_ASSERT(parent);
     QString list_uid = this->name();
     return (parent) ?
-        parent->insertLeaf(name, command, shortcut, list_uid) : Q_NULLPTR;
+        parent->insertLeaf(name, command, shortcut, list_uid) : nullptr;
 }
 
 //*****************************************************************************
 //*****************************************************************************
+
+#include "moc_MenuList.cpp"
