@@ -15,7 +15,6 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "config.h"
 
 #include <new>
 
@@ -36,7 +35,7 @@ QList<Kwave::MenuNode *> Kwave::MenuRoot::m_garbage;
 
 //***************************************************************************
 Kwave::MenuRoot::MenuRoot(QMenuBar &bar)
-    :Kwave::MenuNode(Q_NULLPTR, _("(root)"), QString(), 0, QString()),
+    :Kwave::MenuNode(nullptr, _("(root)"), QString(), 0, QString()),
      m_menu_bar(bar), m_group_list()
 {
 }
@@ -64,8 +63,7 @@ void Kwave::MenuRoot::insertNode(const QString &name,
 
     // now delete all leafs that have been converted to branches
     while (!m_garbage.isEmpty()) {
-        Kwave::MenuNode *node = m_garbage.takeFirst();
-        if (node) delete node;
+        delete m_garbage.takeFirst();
     }
 }
 
@@ -77,14 +75,14 @@ Kwave::MenuSub *Kwave::MenuRoot::insertBranch(const QString &name,
 {
     QMenu *menu = m_menu_bar.addMenu(name);
     Q_ASSERT(menu);
-    if (!menu) return Q_NULLPTR;
+    if (!menu) return nullptr;
 
     Kwave::MenuSub *sub = new(std::nothrow)
         Kwave::MenuSub(this, menu, name, command, shortcut, uid);
     Q_ASSERT(sub);
-    if (!sub) return Q_NULLPTR;
+    if (!sub) return nullptr;
 
-    insertChild(sub, Q_NULLPTR);
+    insertChild(sub, nullptr);
 
     return sub;
 }
@@ -98,9 +96,9 @@ Kwave::MenuNode *Kwave::MenuRoot::insertLeaf(const QString &name,
     Kwave::MenuItem *item = new(std::nothrow)
         Kwave::MenuItem(this, name, command, shortcut, uid);
     Q_ASSERT(item);
-    if (!item) return Q_NULLPTR;
+    if (!item) return nullptr;
 
-    insertChild(item, Q_NULLPTR);
+    insertChild(item, nullptr);
     m_menu_bar.addAction(item->action());
 
     return item;
@@ -127,7 +125,7 @@ void Kwave::MenuRoot::showChild(Kwave::MenuSub *child)
     if (groupList().contains(child->name())) return;
 
     // find the menu bar entry after which we can insert
-    QAction *action_before = Q_NULLPTR;
+    QAction *action_before = nullptr;
     QListIterator<Kwave::MenuNode *> it(m_children);
     it.toBack();
     while (it.hasPrevious()) {
@@ -181,3 +179,5 @@ void Kwave::MenuRoot::deleteLater(Kwave::MenuNode *node)
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_MenuRoot.cpp"
