@@ -16,7 +16,6 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#include "config.h"
 
 #include <QDir>
 #include <QMouseEvent>
@@ -96,3 +95,5 @@ void Kwave::MultiStateWidget::paintEvent(QPaintEvent *)
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_MultiStateWidget.cpp"
