@@ -19,6 +19,7 @@
 #define VIEW_ITEM_H
 
 #include "config.h"
+#include "libkwavegui_export.h"
 
 #include <QtGlobal>
 #include <QCursor>
@@ -29,7 +30,6 @@
 
 #include "libkwave/Sample.h"
 
-class QCursor;
 class QMenu;
 
 namespace Kwave
@@ -38,7 +38,7 @@ namespace Kwave
     class SignalManager;
     class SignalView;
 
-    class Q_DECL_EXPORT ViewItem: public QObject
+    class LIBKWAVEGUI_EXPORT ViewItem: public QObject
     {
         Q_OBJECT
 
@@ -59,7 +59,7 @@ namespace Kwave
         ViewItem(Kwave::SignalView &view, Kwave::SignalManager &signal_manager);
 
         /** Destructor */
-        virtual ~ViewItem();
+        ~ViewItem() override;
 
         /**
          * Returns flags describing the possible interactions with this object
