@@ -18,6 +18,7 @@
 #define LABEL_H
 
 #include "config.h"
+#include "libkwave_export.h"
 
 #include <QtGlobal>
 #include <QString>
@@ -31,7 +32,7 @@
 namespace Kwave
 {
 
-    class Q_DECL_EXPORT Label: public Kwave::MetaData
+    class LIBKWAVE_EXPORT Label: public Kwave::MetaData
     {
     public:
 
@@ -53,7 +54,7 @@ namespace Kwave
         Label(sample_index_t position, const QString &name);
 
         /** destructor */
-        virtual ~Label();
+        virtual ~Label() override;
 
         /** returns the identifier of the "type" of this meta data object */
         static QString metaDataType() { return _("Label"); }
