@@ -20,6 +20,7 @@
 #define MULTI_STREAM_WRITER_H
 
 #include "config.h"
+#include "libkwave_export.h"
 
 #include <QtGlobal>
 #include <QList>
@@ -34,7 +35,7 @@ namespace Kwave
      * A MultiStreamWriter encapsulates a set of <c>StreamWriter</c>s for
      * easier use of multi-track signals.
      */
-    class Q_DECL_EXPORT MultiStreamWriter: public Kwave::MultiWriter
+    class LIBKWAVE_EXPORT MultiStreamWriter: public Kwave::MultiWriter
     {
         Q_OBJECT
 
@@ -44,7 +45,7 @@ namespace Kwave
         explicit MultiStreamWriter(unsigned int tracks);
 
         /** Destructor */
-        virtual ~MultiStreamWriter();
+        virtual ~MultiStreamWriter() override;
 
     };
 }
