@@ -20,6 +20,7 @@
 #define SAMPLE_READER_H
 
 #include "config.h"
+#include "libkwave_export.h"
 
 #include <QtGlobal>
 #include <QElapsedTimer>
@@ -36,7 +37,7 @@
 namespace Kwave
 {
 
-    class Q_DECL_EXPORT SampleReader: public Kwave::SampleSource
+    class LIBKWAVE_EXPORT SampleReader: public Kwave::SampleSource
     {
         Q_OBJECT
     public:
@@ -50,7 +51,7 @@ namespace Kwave
         SampleReader(Kwave::ReaderMode mode, Kwave::Stripe::List stripes);
 
         /** Destructor */
-        virtual ~SampleReader() Q_DECL_OVERRIDE;
+        ~SampleReader() override;
 
         /** Resets the stream to it's start */
         void reset();
@@ -60,7 +61,7 @@ namespace Kwave
          * sample data. It then should emit a signal like this:
          * "output(SampleArray &data)"
          */
-        virtual void goOn() Q_DECL_OVERRIDE;
+        void goOn() override;
 
         /** Checks if the last read operation has reached the end of input */
         inline bool eof() const {
@@ -74,7 +75,7 @@ namespace Kwave
          * @return true if it can produce more sample data, otherwise false
          * @see eof()
          */
-        virtual bool done() const Q_DECL_OVERRIDE { return eof(); }
+        bool done() const override { return eof(); }
 
         /**
          * Reads samples into a buffer.
