@@ -42,10 +42,7 @@ namespace Kwave
         explicit WorkerThread(Kwave::Runnable *runnable, QVariant params);
 
         /** Destructor, calls stop() if the thread is still running. */
-        ~WorkerThread() override;
-
-        /** Starts the thread's execution. */
-        virtual void start();
+        virtual ~WorkerThread() override;
 
         /**
          * Stops the thread execution. Please note that you <b>MUST</b> call
