@@ -157,7 +157,7 @@ bool Kwave::UndoAddMetaDataAction::store(Kwave::SignalManager &)
 Kwave::UndoAction *Kwave::UndoAddMetaDataAction::undo(
     Kwave::SignalManager &manager, bool with_redo)
 {
-    Kwave::UndoAction *redo = Q_NULLPTR;
+    Kwave::UndoAction *redo = nullptr;
 
     Kwave::MetaDataList meta_data =
         manager.metaData().copy(m_offset, m_length);
