@@ -27,7 +27,7 @@
 #include "StringEnterDialog.h"
 
 /** group for loading/saving the configuration */
-#define CONFIG_GROUP metaObject()->className()
+#define CONFIG_GROUP QLatin1StringView(metaObject()->className())
 
 /** entry for loading/saving the width in the configuration */
 #define CONFIG_WIDTH "width"
@@ -87,3 +87,5 @@ void Kwave::StringEnterDialog::invokeHelp()
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_StringEnterDialog.cpp"
